<?php
/**
 * The loop that displays posts.
 *
 * The loop displays the posts and the post content.  See
 * http://codex.wordpress.org/The_Loop to understand it and
 * http://codex.wordpress.org/Template_Tags to understand
 * the tags used in it.
 *
 * @package WordPress
 * @subpackage Outset
 */
?>

<?php /* If there are no posts to display, such as an empty archive page */ ?>
<?php if ( ! have_posts() ) : ?>
	<div id="post-0" class="post error404 not-found">
		<h1 class="entry-title"><?php _e( 'Not Found', 'outset' ); ?></h1>
		<div class="entry-content">
			<p><?php _e( 'Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.', 'outset' ); ?></p>
			<?php get_search_form(); ?>
		</div><!-- .entry-content -->
	</div><!-- #post-0 -->
<?php endif; ?>

<?php
/* Start the Loop.
 *
 * In Outset we use the same loop in multiple contexts.
 * Additionally, we sometimes check for whether we are on an
 * archive page, a search page, etc., allowing for small differences
 * in the loop on each template without actually duplicating
 * the rest of the loop that is shared.
 *
 * Without further ado, the loop:
 */ ?>
<?php while ( have_posts() ) : the_post(); ?>
	<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
    	<h2 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'outset' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>
        
        <div class="comment-count"><?php comments_popup_link('0', '1', '%'); ?></div>
        
        <div class="entry-meta">
			<?php outset_posted_on(); ?>
		</div><!-- .entry-meta -->
        
        <?php if ( (is_home() || is_archive() || is_search()) && (get_option('outset_autoexcerpts') == "off" || get_option('outset_autoexcerpts') == "") ) : // Only display excerpts for archives and search. ?>
        <div class="entry-thumbnail">
			<?php the_thumbnail( 600, 220, "full", "", "", 1, TRUE ); ?>
		</div><!-- .entry-summary -->
        
        <div class="entry-summary">
			<?php the_excerpt( __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'outset' ) ); ?>
		</div><!-- .entry-summary -->
        <?php else : ?>
        <div class="entry-content">
			<?php the_content( __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'outset' ) ); ?>
			<?php wp_link_pages( array( 'before' => '<div class="page-link">' . __( 'Pages:', 'outset' ), 'after' => '</div>' ) ); ?>
        </div><!-- .entry-content -->
        <?php endif; ?>
        <a href="#"><?php __('read more', 'outset'); ?></a>
        <div class="entry-utility">
        	<?php outset_posted_in(); ?>
        </div><!-- .entry-utility -->
    </div><!-- #post-## -->
<?php endwhile; ?>

<?php include('library/includes/navigation.php'); // Display navigation to next/previous pages when applicable ?>